@@ -349,6 +349,12 @@ class Spec(with_metaclass(abc.ABCMeta, object)):
         The path to the "kubectl" program for the 'docker' transport.
         """
 
+    @abc.abstractmethod
+    def mitogen_incus_path(self):
+        """
+        The path to the "incus" program for the 'incus' transport.
+        """
+
     @abc.abstractmethod
     def mitogen_lxc_path(self):
         """
@@ -584,6 +590,9 @@ class PlayContextSpec(Spec):
     def mitogen_kubectl_path(self):
         return self._connection.get_task_var('mitogen_kubectl_path')
 
+    def mitogen_incus_path(self):
+        return self._connection.get_task_var('mitogen_incus_path')
+
     def mitogen_lxc_path(self):
         return self._connection.get_task_var('mitogen_lxc_path')
 
@@ -832,6 +841,9 @@ class MitogenViaSpec(Spec):
     def mitogen_kubectl_path(self):
         return self._host_vars.get('mitogen_kubectl_path')
 
+    def mitogen_incus_path(self):
+        return self._host_vars.get('mitogen_incus_path')
+
     def mitogen_lxc_path(self):
         return self._host_vars.get('mitogen_lxc_path')
 
