@@ -40,14 +40,10 @@ try:
 except ImportError:
     from pipes import quote as shlex_quote
 
+import mitogen.core
 import mitogen.parent
 from mitogen.core import b
 
-try:
-    any
-except NameError:
-    from mitogen.core import any
-
 
 LOG = logging.getLogger(__name__)
 
@@ -72,7 +68,10 @@ PASSWORD_PROMPT_PATTERN = re.compile(
 )
 
 HOSTKEY_REQ_PATTERN = re.compile(
-    b(r'are you sure you want to continue connecting \(yes/no\)\?'),
+    b(
+            r'are you sure you want to continue connecting '
+            r'\(yes/no(?:/\[fingerprint\])?\)\?'
+    ),
     re.I
 )
 
@@ -221,6 +220,14 @@ class Connection(mitogen.parent.Connection):
 
     child_is_immediate_subprocess = False
 
+    # strings that, if escaped, cause problems creating connections
+    # example: `source /opt/rh/rh-python36/enable && python`
+    # is an acceptable ansible_python_version but shlex would quote the &&
+    # and prevent python from executing
+    SHLEX_IGNORE = [
+        "&&"
+    ]
+
     def _get_name(self):
         s = u'ssh.' + mitogen.core.to_text(self.options.hostname)
         if self.options.port and self.options.port != 22:
@@ -291,4 +298,9 @@ class Connection(mitogen.parent.Connection):
             bits += self.options.ssh_args
         bits.append(self.options.hostname)
         base = super(Connection, self).get_boot_command()
-        return bits + [shlex_quote(s).strip() for s in base]
+
+        base_parts = []
+        for s in base:
+            val = s if s in self.SHLEX_IGNORE else shlex_quote(s).strip()
+            base_parts.append(val)
+        return bits + base_parts
